<?php

namespace Drupal\bisnode\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\bisnode\BisnodeServiceInterface;

/**
 * Class BisnodeWebformForm.
 */
class BisnodeWebformForm extends FormBase {

  /**
   * Drupal\bisnode\BisnodeServiceInterface definition.
   *
   * @var \Drupal\bisnode\BisnodeServiceInterface
   */
  protected $bisnodeWebapi;
  /**
   * Constructs a new BisnodeTestConnectionForm object.
   */
  public function __construct(BisnodeServiceInterface $bisnode_webapi) {
    $this->bisnodeWebapi = $bisnode_webapi;
  }

  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('bisnode.webapi')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'bisnode_webform_settings_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state, $webform = NULL) {
    $this->webform = $webform;

    $elements = $webform->getElementsInitializedFlattenedAndHasValue('view');
    $fields = [];
    foreach ($elements as $key => $element) {
      $fields[$key] = $this->t("@title (%type)", [
        '@title' => ($element['#admin_title'] ?: $element['#title'] ?: $key),
        '%type' => (isset($element['#type']) ? $element['#type'] : ''),
      ]);
    }

    $form['active'] = [
      '#type' => 'checkbox',
      '#title' => 'Active Bisnode',
      '#default_value' => $webform->getThirdPartySetting('bisnode', 'active', FALSE),
    ];

    $form['search_field'] = [
      '#type' => 'select',
      '#title' => $this->t('Search field'),
      '#options' => array_merge(['none' => $this->t('No field')], $fields),
      '#default_value' => $webform->getThirdPartySetting('bisnode', 'search_field', 'none'),
    ];

    $form['loading_text'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Loading text'),
      '#default_value' => $webform->getThirdPartySetting('bisnode', 'loading_text', ''),
    ];

    $form['mapping_fields'] = [
      '#type' => 'fieldset',
      '#title' => $this->t('Mapping Fields'),
      '#tree' => TRUE,
    ];


    $mapping = [
      'none' => $this->t('No mapped'),
    ] + $this->bisnodeWebapi::fieldsMapping();

    $mapping_fields = $webform->getThirdPartySetting('bisnode', 'mapping_fields', []);
    foreach ($fields as $key => $field) {
      $form['mapping_fields'][$key] = [
        '#type' => 'select',
        '#title' => $field,
        '#options' => $mapping,
        '#default_value' => isset($mapping_fields[$key]) ? $mapping_fields[$key] : NULL,
      ];
    }

    $form['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Submit'),
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    parent::validateForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $webform = $this->webform;

    $webform->setThirdPartySetting('bisnode', 'active', $form_state->getValue('active'));
    $webform->setThirdPartySetting('bisnode', 'search_field', $form_state->getValue('search_field'));
    $webform->setThirdPartySetting('bisnode', 'loading_text', $form_state->getValue('loading_text'));
    $webform->setThirdPartySetting('bisnode', 'mapping_fields', $form_state->getValue('mapping_fields'));

    $webform->save();
  }
}
